==> react-image-annotate_ns_demo-4.0.70.tgz: package/RegionTags/index.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import LockIcon from "@mui/icons-material/Lock";
import Paper from "@mui/material/Paper";
import React from "react";
import DefaultRegionLabel from "../RegionLabel";

var copyWithout = function copyWithout(obj) {
  var newObj = _objectSpread({}, obj);

  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  for (var _i = 0, _args = args; _i < _args.length; _i++) {
    var arg = _args[_i];
    delete newObj[arg];
  }

  return newObj;
};

export var RegionTags = function RegionTags(_ref) {
  var regions = _ref.regions,
      projectRegionBox = _ref.projectRegionBox,
      mouseEvents = _ref.mouseEvents,
      regionClsList = _ref.regionClsList,
      regionTagList = _ref.regionTagList,
      onBeginRegionEdit = _ref.onBeginRegionEdit,
      onChangeRegion = _ref.onChangeRegion,
      onCloseRegionEdit = _ref.onCloseRegionEdit,
      onDeleteRegion = _ref.onDeleteRegion,
      layoutParams = _ref.layoutParams,
      imageSrc = _ref.imageSrc,
      RegionEditLabel = _ref.RegionEditLabel,
      onRegionClassAdded = _ref.onRegionClassAdded,
      allowComments = _ref.allowComments,
      invaild_show = _ref.invaild_show,
      delete_annotation = _ref.delete_annotation,
      setdelete_annotation = _ref.setdelete_annotation,
      isReadingMode = _ref.isReadingMode;
  var RegionLabel = RegionEditLabel != null ? RegionEditLabel : DefaultRegionLabel;
  return regions.filter(function (r) {
    return r.visible || r.visible === undefined;
  }).map(function (region) {
    var pbox = projectRegionBox(region); // console.log(pbox)

    var _layoutParams$current = layoutParams.current,
        iw = _layoutParams$current.iw,
        ih = _layoutParams$current.ih;
    var margin = 8;
    if (region.highlighted && region.type === "box") margin += 6;
    var labelBoxHeight = region.editingLabels && !region.locked ? 170 : region.tags ? 60 : 50;
    var displayOnTop = pbox.y > labelBoxHeight;
    var coords = displayOnTop ? {
      left: pbox.x,
      top: pbox.y - margin / 2
    } : {
      left: pbox.x,
      top: pbox.y + pbox.h + margin / 2
    };

    if (region.locked) {
      return /*#__PURE__*/React.createElement("div", {
        key: region.id,
        style: _objectSpread({
          position: "absolute"
        }, coords, {
          zIndex: 10 + (region.editingLabels ? 5 : 0)
        })
      }, /*#__PURE__*/React.createElement(Paper, {
        style: _objectSpread({
          position: "absolute",
          left: 0
        }, displayOnTop ? {
          bottom: 0
        } : {
          top: 0
        }, {
          zIndex: 10,
          backgroundColor: "#fff",
          borderRadius: 4,
          padding: 2,
          paddingBottom: 0,
          opacity: 0.5,
          pointerEvents: "none"
        })
      }, /*#__PURE__*/React.createElement(LockIcon, {
        style: {
          width: 16,
          height: 16,
          color: "#333"
        }
      })));
    }

    return /*#__PURE__*/React.createElement("div", {
      key: region.id,
      style: _objectSpread({
        position: "absolute"
      }, coords, {
        zIndex: 15,
        width: 200
      }),
      onMouseDown: function onMouseDown(e) {
        return e.preventDefault();
      },
      onMouseUp: function onMouseUp(e) {
        return e.preventDefault();
      },
      onMouseEnter: function onMouseEnter(e) {
        if (region.editingLabels) {
          mouseEvents.onMouseUp(e);
          e.button = 1;
          mouseEvents.onMouseUp(e);
        }
      }
    }, /*#__PURE__*/React.createElement("div", Object.assign({
      style: _objectSpread({
        position: "absolute",
        zIndex: 20,
        left: 0
      }, displayOnTop ? {
        bottom: 0
      } : {
        top: 0
      })
    }, !region.editingLabels ? copyWithout(mouseEvents, "onMouseDown", "onMouseUp") : {}), /*#__PURE__*/React.createElement(RegionLabel, {
      allowedClasses: regionClsList,
      allowedTags: regionTagList,
      onOpen: onBeginRegionEdit,
      onChange: onChangeRegion,
      onClose: onCloseRegionEdit,
      onDelete: onDeleteRegion,
      editing: region.editingLabels,
      region: region,
      regions: regions,
      imageSrc: imageSrc,
      onRegionClassAdded: onRegionClassAdded,
      allowComments: allowComments,
      invaild_show: invaild_show,
      delete_annotation: delete_annotation,
      setdelete_annotation: setdelete_annotation,
      isReadingMode: isReadingMode
    })));
  });
};
export default RegionTags;

==> react-image-annotate_ns_demo-4.0.72.tgz: package/RegionTags/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import LockIcon from "@mui/icons-material/Lock";
import Paper from "@mui/material/Paper";
import React from "react";
import DefaultRegionLabel from "../RegionLabel";

var copyWithout = function copyWithout(obj) {
  var newObj = _objectSpread({}, obj);

  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  for (var _i = 0, _args = args; _i < _args.length; _i++) {
    var arg = _args[_i];
    delete newObj[arg];
  }

  return newObj;
};

export var RegionTags = function RegionTags(_ref) {
  var regions = _ref.regions,
      projectRegionBox = _ref.projectRegionBox,
      mouseEvents = _ref.mouseEvents,
      regionClsList = _ref.regionClsList,
      regionTagList = _ref.regionTagList,
      onBeginRegionEdit = _ref.onBeginRegionEdit,
      onChangeRegion = _ref.onChangeRegion,
      onCloseRegionEdit = _ref.onCloseRegionEdit,
      onDeleteRegion = _ref.onDeleteRegion,
      layoutParams = _ref.layoutParams,
      imageSrc = _ref.imageSrc,
      RegionEditLabel = _ref.RegionEditLabel,
      onRegionClassAdded = _ref.onRegionClassAdded,
      allowComments = _ref.allowComments,
      invaild_show = _ref.invaild_show,
      delete_annotation = _ref.delete_annotation,
      setdelete_annotation = _ref.setdelete_annotation,
      isReadingMode = _ref.isReadingMode;
  var RegionLabel = RegionEditLabel != null ? RegionEditLabel : DefaultRegionLabel;
  return regions.filter(function (r) {
    return r.visible || r.visible === undefined;
  }).map(function (region) {
    var _ploygonRegion$, _ploygonRegion$2;

    var pbox = projectRegionBox(region); // console.log(pbox)

    var _layoutParams$current = layoutParams.current,
        iw = _layoutParams$current.iw,
        ih = _layoutParams$current.ih;
    var margin = 8;
    if (region.highlighted && region.type === "box") margin += 6;
    var labelBoxHeight = region.editingLabels && !region.locked ? 170 : region.tags ? 60 : 50;
    var displayOnTop = pbox.y > labelBoxHeight;
    var ploygonRegion = region.points.map(function (_ref2) {
      var _ref3 = _slicedToArray(_ref2, 2),
          x = _ref3[0],
          y = _ref3[1];

      return [x * iw, y * ih];
    });
    var coords = displayOnTop ? {
      left: pbox.x,
      top: pbox.y - margin / 2
    } : {
      left: pbox.x,
      top: pbox.y + pbox.h + margin / 2
    };

    if (region.locked) {
      return /*#__PURE__*/React.createElement("div", {
        key: region.id,
        style: _objectSpread({
          position: "absolute"
        }, coords, {
          zIndex: 10 + (region.editingLabels ? 5 : 0)
        })
      }, /*#__PURE__*/React.createElement(Paper, {
        style: _objectSpread({
          position: "absolute",
          left: 0
        }, displayOnTop ? {
          bottom: 0
        } : {
          top: 0
        }, {
          zIndex: 10,
          backgroundColor: "#fff",
          borderRadius: 4,
          padding: 2,
          paddingBottom: 0,
          opacity: 0.5,
          pointerEvents: "none"
        })
      }, /*#__PURE__*/React.createElement(LockIcon, {
        style: {
          width: 16,
          height: 16,
          color: "#333"
        }
      })));
    }

    return /*#__PURE__*/React.createElement("div", {
      key: region.id,
      id: region.id,
      style: _objectSpread({
        position: "absolute"
      }, coords, {
        zIndex: 15,
        width: 200
      }, {
        left: region.type === "polygon" ? (ploygonRegion === null || ploygonRegion === void 0 ? void 0 : (_ploygonRegion$ = ploygonRegion[0]) === null || _ploygonRegion$ === void 0 ? void 0 : _ploygonRegion$[0]) || coords.left : coords.left,
        top: region.type === "polygon" ? (ploygonRegion === null || ploygonRegion === void 0 ? void 0 : (_ploygonRegion$2 = ploygonRegion[0]) === null || _ploygonRegion$2 === void 0 ? void 0 : _ploygonRegion$2[1]) || coords.top : coords.top
      }),
      onMouseDown: function onMouseDown(e) {
        return e.preventDefault();
      },
      onMouseUp: function onMouseUp(e) {
        return e.preventDefault();
      },
      onMouseEnter: function onMouseEnter(e) {
        if (region.editingLabels) {
          mouseEvents.onMouseUp(e);
          e.button = 1;
          mouseEvents.onMouseUp(e);
        }
      }
    }, console.log(ploygonRegion[0][0], ploygonRegion[0][1]), /*#__PURE__*/React.createElement("div", Object.assign({
      style: _objectSpread({
        position: "absolute",
        zIndex: 20,
        left: 0
      }, displayOnTop ? {
        bottom: 0
      } : {
        top: 0
      })
    }, !region.editingLabels ? copyWithout(mouseEvents, "onMouseDown", "onMouseUp") : {}), /*#__PURE__*/React.createElement(RegionLabel, {
      allowedClasses: regionClsList,
      allowedTags: regionTagList,
      onOpen: onBeginRegionEdit,
      onChange: onChangeRegion,
      onClose: onCloseRegionEdit,
      onDelete: onDeleteRegion,
      editing: region.editingLabels,
      region: region,
      regions: regions,
      imageSrc: imageSrc,
      onRegionClassAdded: onRegionClassAdded,
      allowComments: allowComments,
      invaild_show: invaild_show,
      delete_annotation: delete_annotation,
      setdelete_annotation: setdelete_annotation,
      isReadingMode: isReadingMode
    })));
  });
};
export default RegionTags;
